CaptureMatches

Type Alias CaptureMatches 

pub type CaptureMatches<'r, 'h> = FindIter<'r, 'h>;
Iterator that yields Match objects with full capture state (an alias of FindIter in this implementation, since matches always carry captures).

Aliased Type

pub struct CaptureMatches<'r, 'h> { /* private fields */ }