Type Alias CaptureMatches
Source pub type CaptureMatches<'r, 'h> = FindIter<'r, 'h>;
Iterator that yields Match objects with full capture state (an alias of
FindIter in this implementation, since matches always carry captures).
pub struct CaptureMatches<'r, 'h> { }